==> vpn-user-portal-3.5.6.tgz: vpn-user-portal/locale/sv-SE.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => '#Anslutningar inom 5 minuters intervall',
    //'#Unique Guest Users' => '',
    '#Unique Users' => '#Unika användare',
    '#Unique users and max #connections per day' => '#Unika användare och max #anslutningar per dag',
    'ACL Permission List' => 'ACL behörighetslista',
    'Account' => 'Konto',
    'Active' => 'Aktiv',
    'Active Configurations' => 'Aktiva konfigurationer',
    'Aggregated' => 'Aggregerad',
    'All' => 'Alla',
    'An application attempts to establish a VPN connection.' => 'Ett program försöker upprätta en VPN-anslutning.',
    'An error occurred.' => 'Ett fel uppstod',
    'Application Usage' => 'Användning av program',
    'Approve' => 'Tillåt',
    'Approve Application' => 'Tillåt program',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Auktoriserade program',
    'Authorized On' => 'Auktoriserad den',
    'Available Profiles' => 'Tillgängliga profiler',
    'Block LAN' => 'Blockera LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU användning',
    'Change Password' => 'Byt lösenord',
    'Configurations' => 'Konfigurationer',
    'Confirm' => 'Bekräfta',
    'Connected' => 'Ansluten',
    'Connections' => 'Anslutningar',
    'Created On' => 'Skapad den',
    'Current Password' => 'Nuvarande lösenord',
    'Current Password not correct!' => 'Nuvarande lösenord är inte korrekt!',
    'Currently there are no clients connected to this profile.' => 'För närvarande finns det inga klienter kopplade till den här profilen.',
    'DNS Search Domain(s)' => 'DNS sökdomän(er)',
    'DNS Server(s)' => 'DNS server/servrar',
    'Danger Zone' => 'Farozon',
    'Date/Time' => 'Datum/tid',
    'Default Gateway' => 'Standardgateway',
    'Delete' => 'Ta bort',
    'Delete Account' => 'Radera konto',
    'Delete Account Data' => 'Radera kontodata',
    'Disable Account' => 'Inaktivera konto',
    'Disabled' => 'Inaktiverad',
    'Disconnected' => 'Frånkopplad',
    'Distribution of unique users over the VPN applications.' => 'Fördelning av unika användare över VPN-program.',
    'Download' => 'Ladda ner',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Det är inte tillåtet att ladda ned VPN-konfigurationer. Använd ett VPN-program.',
    'Enable Account' => 'Aktivera konto',
    'Error' => 'Fel',
    'Excluded Route(s)' => 'Undantagna routes',
    'Expires On' => 'Upphör att gälla på',
    'Export (CSV)' => 'Exportera (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Hitta användaridentifieraren som använde en IPv4- eller IPv6-adress vid en viss tidpunkt.',
    'Fingerprint' => 'Fingerprint',
    'Here you can change the password for your account.' => 'Här kan du ändra lösenordet för ditt konto',
    'Home' => 'Hem',
    'Hostname' => 'Hostnamn',
    'IP Address' => 'IP adress',
    'IPs' => 'IPs',
    'IPv4 Prefix' => 'IPv4 Prefix',
    'IPv6 Prefix' => 'IPv6 Prefix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importera eller kopiera/klistra in den här konfigurationen till din WireGuard applikation.',
    'Info' => 'Information',
    'Issues' => 'Problem',
    'Live' => 'Live',
    'Log' => 'Logg',
    //'MTU' => '',
    'Max #Connections' => 'Max #anslutningar',
    'More' => 'Mer',
    'N/A' => 'Ej tillämpligt',
    'Name' => 'Namn',
    'New Configuration' => 'Ny konfiguration',
    'New Password' => 'Nytt lösenord',
    'New Password (confirm)' => 'Nytt lösenord (bekräfta)',
    'New Password and New Password (confirm) MUST match!' => 'Nytt lösenord och nytt lösenord (bekräfta) MÅSTE vara lika!',
    'No Permission(s)' => 'Ingen behörighet/Inga behörigheter',
    'No VPN profiles are available for your account.' => 'Inga VPN-profiler är tillgängliga för ditt konto.',
    'Node URL' => 'Nod URL',
    'Node(s)' => 'Nod(er)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Hämta en ny VPN-konfigurationsfil för användning i din VPN-klient.',
    'Offered Ports' => 'Erbjudna portar',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Godkänn bara detta när du försöker upprätta en VPN-anslutning med den här applikationen!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'OpenVPN Server Log',
    'Password' => 'Lösenord',
    'Permissions' => 'Behörigheter',
    'Please sign in with your username and password.' => 'Logga in med ditt användarnamn och lösenord.',
    'Port' => 'Port',
    'Ports' => 'Portar',
    'Preferred Protocol' => 'Önskat protokoll',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Profilanvändning',
    'Profile(s)' => 'Profil(er)',
    'Public Key' => 'Publik nyckel',
    //'Refresh' => '',
    'Results' => 'Resultat',
    'Revoke' => 'Återkalla',
    'Route(s)' => 'Route(s)',
    'Search' => 'Sök',
    'Select a profile and choose a name, e.g. "Phone".' => 'Välj en profil och välj ett namn, t.ex. "Telefon".',
    'Server' => 'Server',
    'Sign In' => 'Logga in',
    'Sign Out' => 'Logga ut',
    'Stats' => 'Statistik',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Datum/Tid</em> MÅSTE vara i UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => '<em>Datum/Tid</em>-fältet tillåter följande datumformat <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Autentiseringsuppgifterna som du angav var inte korrekta.',
    'The list of applications you authorized to create a VPN connection.' => 'Listan över program som du har auktoriserat för att skapa en VPN-anslutning.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Det maximala antalet samtidigt anslutna VPN-klienter vid en viss tidpunkt under den senaste veckan',
    'The most recent VPN connections with this account.' => 'De senaste VPN-anslutningarna för det här kontot.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'Antalet unika användare som anslutit sig till VPN-tjänsten under den senaste veckan',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabellen nedan visar VPN-användningen per profil under den senaste veckan.',
    'There are no results matching your criteria.' => 'Det finns inga resultat som matchar dina kriterier.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Den här servern använder en extern autentiseringskälla. Att ta bort kontodata hindrar inte användaren från att autentisera (igen)!',
    'This user does not have any active configurations.' => 'Den här användaren har inga aktiva konfigurationer.',
    'This user does not have any connections.' => 'Den här användaren har inga anslutningar.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'För att förhindra att skadliga program i hemlighet upprättar en VPN-anslutning för din räkning måste du uttryckligen godkänna det här programmet först.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Använd WireGuard-appen på din mobila enhet för att skanna denna QR-kod.',
    'User ID' => 'Användar-ID',
    'Username' => 'Användarnamn',
    'Users' => 'Användare',
    'VPN Portal' => 'VPN portal',
    'Version' => 'Version',
    'Welcome to this VPN service!' => 'Välkommen till denna VPN-tjänst!',
    'Why is this necessary?' => 'Varför är detta nödvändigt?',
    'WireGuard' => 'WireGuard',
    'WireGuard Configuration' => 'WireGuard konfiguration',
    'You can download the detailed VPN usage statistics below.' => 'Du kan ladda ner den detaljerade VPN-användningsstatistiken nedan.',
    'You cannot manage your own user account.' => 'Du kan inte hantera ditt eget användarkonto.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Du har nått det maximala antalet tillåtna aktiva VPN-konfigurationer. Ta bort några först.',
    'Your account does not have access to any VPN profile.' => 'Ditt konto har inte tillgång till någon VPN-profil.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Din nya konfigurationen upphör att gälla den %expiryDate%. Kom tillbaka hit för att få en ny konfiguration efter utgångsdatum!',
];

==> vpn-user-portal-3.9.4.tgz: vpn-user-portal/locale/sv-SE.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => '#Anslutningar inom 5 minuters intervall',
    //'#Unique Guest Users' => '',
    '#Unique Users' => '#Unika användare',
    '#Unique users and max #connections per day' => '#Unika användare och max #anslutningar per dag',
    'ACL Permission List' => 'ACL behörighetslista',
    'Account' => 'Konto',
    'Active' => 'Aktiv',
    'Active Configurations' => 'Aktiva konfigurationer',
    //'Additional Credential' => '',
    'Aggregated' => 'Aggregerad',
    'All' => 'Alla',
    'An application attempts to establish a VPN connection.' => 'Ett program försöker upprätta en VPN-anslutning.',
    'An error occurred.' => 'Ett fel uppstod',
    'Application Usage' => 'Användning av program',
    'Approve' => 'Tillåt',
    'Approve Application' => 'Tillåt program',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Auktoriserade program',
    'Authorized On' => 'Auktoriserad den',
    'Available Profiles' => 'Tillgängliga profiler',
    'Block LAN' => 'Blockera LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU användning',
    'Change Password' => 'Byt lösenord',
    'Configurations' => 'Konfigurationer',
    'Confirm' => 'Bekräfta',
    'Connected' => 'Ansluten',
    'Connections' => 'Anslutningar',
    'Created On' => 'Skapad den',
    'Current Password' => 'Nuvarande lösenord',
    'Current Password not correct!' => 'Nuvarande lösenord är inte korrekt!',
    'Currently there are no clients connected to this profile.' => 'För närvarande finns det inga klienter kopplade till den här profilen.',
    'DNS Search Domain(s)' => 'DNS sökdomän(er)',
    'DNS Server(s)' => 'DNS server/servrar',
    'Danger Zone' => 'Farozon',
    //'Database' => '',
    'Date/Time' => 'Datum/tid',
    'Default Gateway' => 'Standardgateway',
    'Delete' => 'Ta bort',
    'Delete Account' => 'Radera konto',
    'Delete Account Data' => 'Radera kontodata',
    'Disable Account' => 'Inaktivera konto',
    'Disabled' => 'Inaktiverad',
    'Disconnected' => 'Frånkopplad',
    'Distribution of unique users over the VPN applications.' => 'Fördelning av unika användare över VPN-program.',
    'Download' => 'Ladda ner',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Det är inte tillåtet att ladda ned VPN-konfigurationer. Använd ett VPN-program.',
    //'Driver' => '',
    'Enable Account' => 'Aktivera konto',
    'Error' => 'Fel',
    'Excluded Route(s)' => 'Undantagna routes',
    'Expires On' => 'Upphör att gälla på',
    'Export (CSV)' => 'Exportera (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Hitta användaridentifieraren som använde en IPv4- eller IPv6-adress vid en viss tidpunkt.',
    'Fingerprint' => 'Fingerprint',
    'Here you can change the password for your account.' => 'Här kan du ändra lösenordet för ditt konto',
    'Home' => 'Hem',
    'Hostname' => 'Hostnamn',
    'IP Address' => 'IP adress',
    'IPs' => 'IPs',
    'IPv4 Prefix' => 'IPv4 Prefix',
    'IPv6 Prefix' => 'IPv6 Prefix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importera eller kopiera/klistra in den här konfigurationen till din WireGuard applikation.',
    'Info' => 'Information',
    'Issues' => 'Problem',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Live',
    'Log' => 'Logg',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => 'Max #anslutningar',
    'More' => 'Mer',
    'N/A' => 'Ej tillämpligt',
    'Name' => 'Namn',
    'New Configuration' => 'Ny konfiguration',
    'New Password' => 'Nytt lösenord',
    'New Password (confirm)' => 'Nytt lösenord (bekräfta)',
    'New Password and New Password (confirm) MUST match!' => 'Nytt lösenord och nytt lösenord (bekräfta) MÅSTE vara lika!',
    'No Permission(s)' => 'Ingen behörighet/Inga behörigheter',
    'No VPN profiles are available for your account.' => 'Inga VPN-profiler är tillgängliga för ditt konto.',
    'Node URL' => 'Nod URL',
    'Node(s)' => 'Nod(er)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Hämta en ny VPN-konfigurationsfil för användning i din VPN-klient.',
    'Offered Ports' => 'Erbjudna portar',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Godkänn bara detta när du försöker upprätta en VPN-anslutning med den här applikationen!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'OpenVPN Server Log',
    'Password' => 'Lösenord',
    'Permissions' => 'Behörigheter',
    'Please sign in with your username and password.' => 'Logga in med ditt användarnamn och lösenord.',
    'Port' => 'Port',
    'Ports' => 'Portar',
    'Preferred Protocol' => 'Önskat protokoll',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Profilanvändning',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profil(er)',
    //'Proxy URL' => '',
    'Public Key' => 'Publik nyckel',
    //'Refresh' => '',
    'Results' => 'Resultat',
    'Revoke' => 'Återkalla',
    'Route(s)' => 'Route(s)',
    'Search' => 'Sök',
    'Select a profile and choose a name, e.g. "Phone".' => 'Välj en profil och välj ett namn, t.ex. "Telefon".',
    'Server' => 'Server',
    'Sign In' => 'Logga in',
    'Sign Out' => 'Logga ut',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistik',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Datum/Tid</em> MÅSTE vara i UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => '<em>Datum/Tid</em>-fältet tillåter följande datumformat <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Autentiseringsuppgifterna som du angav var inte korrekta.',
    'The list of applications you authorized to create a VPN connection.' => 'Listan över program som du har auktoriserat för att skapa en VPN-anslutning.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Det maximala antalet samtidigt anslutna VPN-klienter vid en viss tidpunkt under den senaste veckan',
    'The most recent VPN connections with this account.' => 'De senaste VPN-anslutningarna för det här kontot.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'Antalet unika användare som anslutit sig till VPN-tjänsten under den senaste veckan',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabellen nedan visar VPN-användningen per profil under den senaste veckan.',
    'There are no results matching your criteria.' => 'Det finns inga resultat som matchar dina kriterier.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Den här servern använder en extern autentiseringskälla. Att ta bort kontodata hindrar inte användaren från att autentisera (igen)!',
    'This user does not have any active configurations.' => 'Den här användaren har inga aktiva konfigurationer.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Den här användaren har inga anslutningar.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'För att förhindra att skadliga program i hemlighet upprättar en VPN-anslutning för din räkning måste du uttryckligen godkänna det här programmet först.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Använd WireGuard-appen på din mobila enhet för att skanna denna QR-kod.',
    'User ID' => 'Användar-ID',
    'Username' => 'Användarnamn',
    'Users' => 'Användare',
    'VPN Portal' => 'VPN portal',
    'Version' => 'Version',
    'Welcome to this VPN service!' => 'Välkommen till denna VPN-tjänst!',
    'Why is this necessary?' => 'Varför är detta nödvändigt?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard konfiguration',
    'You can download the detailed VPN usage statistics below.' => 'Du kan ladda ner den detaljerade VPN-användningsstatistiken nedan.',
    'You cannot manage your own user account.' => 'Du kan inte hantera ditt eget användarkonto.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Du har nått det maximala antalet tillåtna aktiva VPN-konfigurationer. Ta bort några först.',
    'Your account does not have access to any VPN profile.' => 'Ditt konto har inte tillgång till någon VPN-profil.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Din nya konfigurationen upphör att gälla den %expiryDate%. Kom tillbaka hit för att få en ny konfiguration efter utgångsdatum!',
];
